Module menu_manager

Module menu_manager 

The Menu Manager looks after the menu and where we currently are within it.

Structs

MenuManager
Holds a nested tree of Menus and remembers which menu within the tree we’re currently looking at.